function Get-SPList([uri]$url) {
  # Nullify variables $site, $web and $list
  $site = $web = $list = $null

  # Get site collection
  $site = New-Object -TypeName Microsoft.SharePoint.SPSite -ArgumentList $([Microsoft.SharePoint.Utilities.SPEncode]::UrlDecodeAsUrl($url.AbsoluteUri));

  # Get site-relative URL
  $webURL = ([Microsoft.SharePoint.Utilities.SPEncode]::UrlDecodeAsUrl($url.AbsoluteUri)) -replace $site.Url;

  # Remove query information if included
  if (-not [string]::IsNullOrEmpty($url.Query)) {
    $webURL = $webURL.Replace($url.Query, [string]::Empty);
  }

  # Process the array of segments backwards,
  # removing segments one by one from the end of the URL,
  # until the URL of the lowest level subsite is identified
  -1..-($url.Segments.Count) | ForEach-Object {
    if ($web -eq $null) {
      # Once the correct URL is obtained, initialize a variable containing an
      # instance of SPWeb class for the lowest level subsite
      if($webUrl -eq "/"){
        $identity = $webUrl
      } else {
        $identity = $webUrl.Trim("/")
      }

      $web = Get-SPWeb -Site $site -Identity $identity -ErrorAction SilentlyContinue;
      $webUrl = $webUrl -replace [Microsoft.SharePoint.Utilities.SPEncode]::UrlDecodeAsUrl($url.Segments[$_]);
    }
  }

  if ($web -ne $null) {
    0..($url.Segments.Count - 1) | ForEach-Object {
      $listUrl += $url.Segments[$_];
      if ($list -eq $null) {
        $list = $(trap {continue}; $web.GetList($listUrl.TrimEnd("/")));
      }
    }
  }

  $web.Dispose();
  $site.Dispose();
  return $list;
}