<#
.SYNOPSIS
Checks out files in a SharePoint document library.

.DESCRIPTION
The script checks out a single file or loops
through a document library and checks out all files.

.PARAMETER url
Site URL.

.PARAMETER folder
Folder/Document library name

.PARAMETER file
File name

.PARAMETER checkOutType
Checkout type Online or Offline

.PARAMETER all
Checks out all files.
#>

param(
[string]$url,
[string]$folder,
[string]$file,
[string]$checkOutType,
[switch]$all
)

# Check if Snap-in is loaded
if(-not(Get-PSSnapin | Where { $_.Name -eq "Microsoft.SharePoint.PowerShell"})) {
  Add-PSSnapin Microsoft.SharePoint.PowerShell;
}

$spWeb = Get-SPWeb -Identity $url;

# Check if All files should be checked out
if($all) {
  # Get the folder
  $spFolder = $spWeb.GetFolder($folder);
  # Store file collection in a variable
  $spFileCollection = $spFolder.Files;
  # Loop through files and check out if file is not already checked out
  $spFileCollection | ForEach-Object {
    # Check if file is not checked out
    if($_.CheckOutType -eq "None") {
      # check out file
      $_.CheckOut($checkOutType,$null);
      Write-Host $_.Name checked out;
    } else {
      Write-Host $_.Name already checked out;
    }
  }
} else {
  # Store file path in a variable
  $fileURL = $folder + "/" + $file;
  $spFile = $spWeb.GetFile($fileURL);
  # Check if file is not checked out
  if($spFile.CheckOutType -eq "None") {
    # Check out file
    $spFile.CheckOut($checkOutType,$null);
    Write-Host $spFile.Name checked out;
  } else {
    Write-Host $spFile.Name already checked out;
  }
}
$spWeb.Dispose()