function Set-SPGroup([string]$url, [string]$group, [string]$name, [string]$owner, [string]$description) {
  $spWeb = Get-SPWeb $url

  # Store groups in collection
  $spGroupCollection = $spWeb.SiteGroups

  # Get group
  $spGroup = $spGroupCollection[$group]

  if($spGroup) {
    # Change group name
    if($name) {
      $oldName = $spGroup.Name
      $spGroup.Name = $name
    }

    # Change owner
    if($owner) {
      if($spWeb.Site.WebApplication.UseClaimsAuthentication) {
        $owner = (New-SPClaimsPrincipal $owner -IdentityType WindowsSamAccountName).ToEncodedString()
      }

      # Ensure user
      if($spWeb.EnsureUser($owner)) {
        $spUser = Get-SPUser -Web $url -Identity $owner
        $spGroup.Owner = $spUser
      }
    }
    # Change description
    if($description) {
      $spGroup.Description = $description;
      # Update item in User Information List
      $spGroupListItem = ($spWeb.Lists["User Information List"].Items | Where-Object {$_["Group"] -eq $oldName})
      $spGroupListItem["Notes"] = $description
      $spGroupListItem.Update()
    }
    # Update group
    $spGroup.Update()
  } else {
    Write-Host "Group: $group not found"
  }
  $spWeb.Dispose()
}