param ([string]$webApplication, [string]$prefix, [string]$file)

function Set-SQL([string]$command, [string]$connectionString) {
  $connection = New-Object System.Data.SQLClient.SQLConnection;
  $connection.ConnectionString = $connectionString;
  $connection.Open();

  $sqlCommand = New-Object System.Data.SQLClient.SQLCommand;
  $sqlCommand.Connection = $Connection;
  $sqlCommand.CommandText = $command;
  $sqlCommand.ExecuteNonQuery();
  $connection.Close();
}

# Create xml template
[xml]$xml = "<ContentDatabases></ContentDatabases>"

# Store XML code in variable
$properties = @"
<Name>{0}</Name>
<NewName></NewName>
<MaxSiteLevel>{1}</MaxSiteLevel>
<WarningSiteLevel>{2}</WarningSiteLevel>
<DatabaseStatus>{3}</DatabaseStatus>
<Server>{4}</Server>
"@

# Enumerate content databases in Web application
Get-SPContentDatabase -WebApplication $webApplication | ForEach-Object {
  # Create new XML element
  $element = $xml.CreateElement("ContentDatabase");
  $element.InnerXml = $properties -f $_.Name, $_.MaximumSiteCount,$_.WarningSiteCount, $_.Status, $_.Server;

  # Append element to the document
  [void]$xml["ContentDatabases"].AppendChild($element);

  # Detach Content Database
  Dismount-SPContentDatabase -Identity $_.ID -Confirm:$false;
}

# Loop through the content databases in the XML file
for ($i=0; $i -lt ([array]$xml.ContentDatabases.ContentDatabase).Count; $i++) {
  # Pick content database to process
  $cd = ([array]$xml.ContentDatabases.ContentDatabase)[$i];

  # Create connection string using Windows integrated authentication
  $connection = "server=" + $cd.Server + ";database=master;trusted_connection=true;"

  # Calculate content databases new name
  $newName = $prefix + "_{0:d2}" -f $($i + 1);

  # Update XML document
  $cd.NewName = $newName;

  # Set the Restrict Access to Single_User, Rename the database to the new name, Set the Restrict Access to Multi_User
  $command = "ALTER DATABASE " + $cd.Name + " SET SINGLE_USER WITH ROLLBACK IMMEDIATE; ALTER DATABASE " + $cd.Name + " MODIFY NAME =" + $cd.newName+"; ALTER DATABASE " + $cd.newName+" SET MULTI_USER";

  # Apply changes SQL
  Set-SQL -command $command -connectionString $connection | Out-Null;

  # Attach content database with new name
  Mount-SPContentDatabase $cd.NewName -DatabaseServer $cd.Server -WebApplication $webApplication -MaxSiteCount $cd.MaxSiteLevel -WarningSiteCount $cd.WarningSiteLevel -Confirm:$false;
}

# Save XML to file on disk for reference
if ($file) {
  $xml.Save($file);
}