function Export-SPUnattachedList([string]$contentDatabase, [string]$databaseServer, [string]$site, [string]$web, [string]$list, [string]$file, [switch]$showSite, [switch]$showWeb, [switch]$showList) {
  $ContentDB = Get-SPContentDatabase -DatabaseServer $DatabaseServer -DatabaseName $ContentDatabase -ConnectAsUnattachedDatabase
  if($showSite) {
    # Return site collections
    $contentDB.Sites | Select-Object -Property @{Name="RelativeURL";Expression={([uri]$_.Url).AbsolutePath}}
    Break
  }

  # Get site collection
  $spSite = $contentDB.Sites[$site]
  if($showWeb) {
    # Return sites
    $spSite.AllWebs | Select-Object -Property @{Name="RelativeURL";Expression={([uri]$_.Url).AbsolutePath}}
    Break
  }

  # Get site
  $spWeb = $spSite.OpenWeb($web)
  if($showList) {
    $spWeb.Lists | Select-Object -Property @{Name="List";Expression={$_.Title}}
    Break
  }

  # Check folder
  if(-not(Test-Path (Split-Path $file))) {
    New-Item -path (Split-Path $file) -type directory | Out-Null
  }

  # Check if file already exists
  if(Test-Path $file) {
    Write-Host "File $file already exists."
    Break
  }

  $spList = $spWeb.Lists[$list]
  $spExportObject = New-Object Microsoft.SharePoint.Deployment.SPExportObject
  $spExportObject.ID = $SPList.ID
  $spExportObject.Type = "List"
  $spExport = New-Object Microsoft.SharePoint.Deployment.SPExport

  # Add content database
  $spExport.Settings.UnattachedContentDatabase = $ContentDB

  # Add object type
  $spExport.Settings.ExportObjects.Add($spExportObject)

  # Add site collection URL
  $spExport.Settings.SiteUrl= $spSite.URL

  # Set additional properties
  $spExport.Settings.BaseFilename = (Split-Path $file -Leaf)
  $spExport.Settings.FileLocation = (Split-Path $file)
  $spExport.Settings.LogFilePath = ($file -Replace "\..*","-log.txt")
  $spExport.Settings.IncludeSecurity = "All"
  $spExport.Settings.IncludeVersions = "All"

  # Initiate export operation
  $spExport.Run()

  # Dispose objects
  $spWeb.Dispose()
  $spSite.Dispose()
  $spExport.Dispose()
}